/* DO NOT EDIT! This file has been generated by gen-dmt.py from DMT-r1-v13.pdf. */

#include "dmt.h"

const struct di_dmt_timing _di_dmt_timings[] = {
	{
		.dmt_id = 0x01,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 640,
		.vert_video = 350,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 31500000,
		.horiz_blank = 192,
		.horiz_front_porch = 32,
		.horiz_sync_pulse = 64,
		.horiz_border = 0,
		.vert_blank = 95,
		.vert_front_porch = 32,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x02,
		.edid_std_id = 0x3119,
		.cvt_id = 0,
		.horiz_video = 640,
		.vert_video = 400,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 31500000,
		.horiz_blank = 192,
		.horiz_front_porch = 32,
		.horiz_sync_pulse = 64,
		.horiz_border = 0,
		.vert_blank = 45,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x03,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 720,
		.vert_video = 400,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 35500000,
		.horiz_blank = 216,
		.horiz_front_porch = 36,
		.horiz_sync_pulse = 72,
		.horiz_border = 0,
		.vert_blank = 46,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x04,
		.edid_std_id = 0x3140,
		.cvt_id = 0,
		.horiz_video = 640,
		.vert_video = 480,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 25175000,
		.horiz_blank = 144,
		.horiz_front_porch = 8,
		.horiz_sync_pulse = 96,
		.horiz_border = 8,
		.vert_blank = 29,
		.vert_front_porch = 2,
		.vert_sync_pulse = 2,
		.vert_border = 8,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x05,
		.edid_std_id = 0x314C,
		.cvt_id = 0,
		.horiz_video = 640,
		.vert_video = 480,
		.refresh_rate_hz = 72.0,
		.pixel_clock_hz = 31500000,
		.horiz_blank = 176,
		.horiz_front_porch = 16,
		.horiz_sync_pulse = 40,
		.horiz_border = 8,
		.vert_blank = 24,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 8,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x06,
		.edid_std_id = 0x314F,
		.cvt_id = 0,
		.horiz_video = 640,
		.vert_video = 480,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 31500000,
		.horiz_blank = 200,
		.horiz_front_porch = 16,
		.horiz_sync_pulse = 64,
		.horiz_border = 0,
		.vert_blank = 20,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x07,
		.edid_std_id = 0x3159,
		.cvt_id = 0,
		.horiz_video = 640,
		.vert_video = 480,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 36000000,
		.horiz_blank = 192,
		.horiz_front_porch = 56,
		.horiz_sync_pulse = 56,
		.horiz_border = 0,
		.vert_blank = 29,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x08,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 800,
		.vert_video = 600,
		.refresh_rate_hz = 56.0,
		.pixel_clock_hz = 36000000,
		.horiz_blank = 224,
		.horiz_front_porch = 24,
		.horiz_sync_pulse = 72,
		.horiz_border = 0,
		.vert_blank = 25,
		.vert_front_porch = 1,
		.vert_sync_pulse = 2,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x09,
		.edid_std_id = 0x4540,
		.cvt_id = 0,
		.horiz_video = 800,
		.vert_video = 600,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 40000000,
		.horiz_blank = 256,
		.horiz_front_porch = 40,
		.horiz_sync_pulse = 128,
		.horiz_border = 0,
		.vert_blank = 28,
		.vert_front_porch = 1,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x0A,
		.edid_std_id = 0x454C,
		.cvt_id = 0,
		.horiz_video = 800,
		.vert_video = 600,
		.refresh_rate_hz = 72.0,
		.pixel_clock_hz = 50000000,
		.horiz_blank = 240,
		.horiz_front_porch = 56,
		.horiz_sync_pulse = 120,
		.horiz_border = 0,
		.vert_blank = 66,
		.vert_front_porch = 37,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x0B,
		.edid_std_id = 0x454F,
		.cvt_id = 0,
		.horiz_video = 800,
		.vert_video = 600,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 49500000,
		.horiz_blank = 256,
		.horiz_front_porch = 16,
		.horiz_sync_pulse = 80,
		.horiz_border = 0,
		.vert_blank = 25,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x0C,
		.edid_std_id = 0x4559,
		.cvt_id = 0,
		.horiz_video = 800,
		.vert_video = 600,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 56250000,
		.horiz_blank = 248,
		.horiz_front_porch = 32,
		.horiz_sync_pulse = 64,
		.horiz_border = 0,
		.vert_blank = 31,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x0D,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 800,
		.vert_video = 600,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 73250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 36,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x0E,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 848,
		.vert_video = 480,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 33750000,
		.horiz_blank = 240,
		.horiz_front_porch = 16,
		.horiz_sync_pulse = 112,
		.horiz_border = 0,
		.vert_blank = 37,
		.vert_front_porch = 6,
		.vert_sync_pulse = 8,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x0F,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1024,
		.vert_video = 768,
		.refresh_rate_hz = 43.0,
		.pixel_clock_hz = 44900000,
		.horiz_blank = 240,
		.horiz_front_porch = 8,
		.horiz_sync_pulse = 176,
		.horiz_border = 0,
		.vert_blank = 24,
		.vert_front_porch = 0,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x10,
		.edid_std_id = 0x6140,
		.cvt_id = 0,
		.horiz_video = 1024,
		.vert_video = 768,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 65000000,
		.horiz_blank = 320,
		.horiz_front_porch = 24,
		.horiz_sync_pulse = 136,
		.horiz_border = 0,
		.vert_blank = 38,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x11,
		.edid_std_id = 0x614A,
		.cvt_id = 0,
		.horiz_video = 1024,
		.vert_video = 768,
		.refresh_rate_hz = 70.0,
		.pixel_clock_hz = 75000000,
		.horiz_blank = 304,
		.horiz_front_porch = 24,
		.horiz_sync_pulse = 136,
		.horiz_border = 0,
		.vert_blank = 38,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x12,
		.edid_std_id = 0x614F,
		.cvt_id = 0,
		.horiz_video = 1024,
		.vert_video = 768,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 78750000,
		.horiz_blank = 288,
		.horiz_front_porch = 16,
		.horiz_sync_pulse = 96,
		.horiz_border = 0,
		.vert_blank = 32,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x13,
		.edid_std_id = 0x6159,
		.cvt_id = 0,
		.horiz_video = 1024,
		.vert_video = 768,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 94500000,
		.horiz_blank = 352,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 96,
		.horiz_border = 0,
		.vert_blank = 40,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x14,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1024,
		.vert_video = 768,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 115500000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 45,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x15,
		.edid_std_id = 0x714F,
		.cvt_id = 0,
		.horiz_video = 1152,
		.vert_video = 864,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 108000000,
		.horiz_blank = 448,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 128,
		.horiz_border = 0,
		.vert_blank = 36,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x55,
		.edid_std_id = 0x81C0,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 720,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 74250000,
		.horiz_blank = 370,
		.horiz_front_porch = 110,
		.horiz_sync_pulse = 40,
		.horiz_border = 0,
		.vert_blank = 30,
		.vert_front_porch = 5,
		.vert_sync_pulse = 5,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x16,
		.edid_std_id = 0,
		.cvt_id = 0x7F1C21,
		.horiz_video = 1280,
		.vert_video = 768,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 68250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 22,
		.vert_front_porch = 3,
		.vert_sync_pulse = 7,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x17,
		.edid_std_id = 0,
		.cvt_id = 0x7F1C28,
		.horiz_video = 1280,
		.vert_video = 768,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 79500000,
		.horiz_blank = 384,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 128,
		.horiz_border = 0,
		.vert_blank = 30,
		.vert_front_porch = 3,
		.vert_sync_pulse = 7,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x18,
		.edid_std_id = 0,
		.cvt_id = 0x7F1C44,
		.horiz_video = 1280,
		.vert_video = 768,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 102250000,
		.horiz_blank = 416,
		.horiz_front_porch = 80,
		.horiz_sync_pulse = 128,
		.horiz_border = 0,
		.vert_blank = 37,
		.vert_front_porch = 3,
		.vert_sync_pulse = 7,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x19,
		.edid_std_id = 0,
		.cvt_id = 0x7F1C62,
		.horiz_video = 1280,
		.vert_video = 768,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 117500000,
		.horiz_blank = 432,
		.horiz_front_porch = 80,
		.horiz_sync_pulse = 136,
		.horiz_border = 0,
		.vert_blank = 41,
		.vert_front_porch = 3,
		.vert_sync_pulse = 7,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x1A,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 768,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 140250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 45,
		.vert_front_porch = 3,
		.vert_sync_pulse = 7,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x1B,
		.edid_std_id = 0,
		.cvt_id = 0x8F1821,
		.horiz_video = 1280,
		.vert_video = 800,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 71000000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 23,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x1C,
		.edid_std_id = 0x8100,
		.cvt_id = 0x8F1828,
		.horiz_video = 1280,
		.vert_video = 800,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 83500000,
		.horiz_blank = 400,
		.horiz_front_porch = 72,
		.horiz_sync_pulse = 128,
		.horiz_border = 0,
		.vert_blank = 31,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x1D,
		.edid_std_id = 0x810F,
		.cvt_id = 0x8F1844,
		.horiz_video = 1280,
		.vert_video = 800,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 106500000,
		.horiz_blank = 416,
		.horiz_front_porch = 80,
		.horiz_sync_pulse = 128,
		.horiz_border = 0,
		.vert_blank = 38,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x1E,
		.edid_std_id = 0x8119,
		.cvt_id = 0x8F1862,
		.horiz_video = 1280,
		.vert_video = 800,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 122500000,
		.horiz_blank = 432,
		.horiz_front_porch = 80,
		.horiz_sync_pulse = 136,
		.horiz_border = 0,
		.vert_blank = 43,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x1F,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 800,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 146250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 47,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x20,
		.edid_std_id = 0x8140,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 960,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 108000000,
		.horiz_blank = 520,
		.horiz_front_porch = 96,
		.horiz_sync_pulse = 112,
		.horiz_border = 0,
		.vert_blank = 40,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x21,
		.edid_std_id = 0x8159,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 960,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 148500000,
		.horiz_blank = 448,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 160,
		.horiz_border = 0,
		.vert_blank = 51,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x22,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 960,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 175500000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 57,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x23,
		.edid_std_id = 0x8180,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 1024,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 108000000,
		.horiz_blank = 408,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 112,
		.horiz_border = 0,
		.vert_blank = 42,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x24,
		.edid_std_id = 0x818F,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 1024,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 135000000,
		.horiz_blank = 408,
		.horiz_front_porch = 16,
		.horiz_sync_pulse = 144,
		.horiz_border = 0,
		.vert_blank = 42,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x25,
		.edid_std_id = 0x8199,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 1024,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 157500000,
		.horiz_blank = 448,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 160,
		.horiz_border = 0,
		.vert_blank = 48,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x26,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1280,
		.vert_video = 1024,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 187250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 60,
		.vert_front_porch = 3,
		.vert_sync_pulse = 7,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x27,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1360,
		.vert_video = 768,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 85500000,
		.horiz_blank = 432,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 112,
		.horiz_border = 0,
		.vert_blank = 27,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x28,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1360,
		.vert_video = 768,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 148250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 45,
		.vert_front_porch = 3,
		.vert_sync_pulse = 5,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x51,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1366,
		.vert_video = 768,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 85500000,
		.horiz_blank = 426,
		.horiz_front_porch = 70,
		.horiz_sync_pulse = 143,
		.horiz_border = 0,
		.vert_blank = 30,
		.vert_front_porch = 3,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x56,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1366,
		.vert_video = 768,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 72000000,
		.horiz_blank = 134,
		.horiz_front_porch = 14,
		.horiz_sync_pulse = 56,
		.horiz_border = 0,
		.vert_blank = 32,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x29,
		.edid_std_id = 0,
		.cvt_id = 0x0C2021,
		.horiz_video = 1400,
		.vert_video = 1050,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 101000000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 30,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x2A,
		.edid_std_id = 0x9040,
		.cvt_id = 0x0C2028,
		.horiz_video = 1400,
		.vert_video = 1050,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 121750000,
		.horiz_blank = 464,
		.horiz_front_porch = 88,
		.horiz_sync_pulse = 144,
		.horiz_border = 0,
		.vert_blank = 39,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x2B,
		.edid_std_id = 0x904F,
		.cvt_id = 0x0C2044,
		.horiz_video = 1400,
		.vert_video = 1050,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 156000000,
		.horiz_blank = 496,
		.horiz_front_porch = 104,
		.horiz_sync_pulse = 144,
		.horiz_border = 0,
		.vert_blank = 49,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x2C,
		.edid_std_id = 0x9059,
		.cvt_id = 0x0C2062,
		.horiz_video = 1400,
		.vert_video = 1050,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 179500000,
		.horiz_blank = 512,
		.horiz_front_porch = 104,
		.horiz_sync_pulse = 152,
		.horiz_border = 0,
		.vert_blank = 55,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x2D,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1400,
		.vert_video = 1050,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 208000000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 62,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x2E,
		.edid_std_id = 0,
		.cvt_id = 0xC11821,
		.horiz_video = 1440,
		.vert_video = 900,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 88750000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 26,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x2F,
		.edid_std_id = 0x9500,
		.cvt_id = 0xC11828,
		.horiz_video = 1440,
		.vert_video = 900,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 106500000,
		.horiz_blank = 464,
		.horiz_front_porch = 80,
		.horiz_sync_pulse = 152,
		.horiz_border = 0,
		.vert_blank = 34,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x30,
		.edid_std_id = 0x950F,
		.cvt_id = 0xC11844,
		.horiz_video = 1440,
		.vert_video = 900,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 136750000,
		.horiz_blank = 496,
		.horiz_front_porch = 96,
		.horiz_sync_pulse = 152,
		.horiz_border = 0,
		.vert_blank = 42,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x31,
		.edid_std_id = 0x9519,
		.cvt_id = 0xC11868,
		.horiz_video = 1440,
		.vert_video = 900,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 157000000,
		.horiz_blank = 512,
		.horiz_front_porch = 104,
		.horiz_sync_pulse = 152,
		.horiz_border = 0,
		.vert_blank = 48,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x32,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1440,
		.vert_video = 900,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 182750000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 53,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x53,
		.edid_std_id = 0xA9C0,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 900,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 108000000,
		.horiz_blank = 200,
		.horiz_front_porch = 24,
		.horiz_sync_pulse = 80,
		.horiz_border = 0,
		.vert_blank = 100,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x33,
		.edid_std_id = 0xA940,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 1200,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 162000000,
		.horiz_blank = 560,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 192,
		.horiz_border = 0,
		.vert_blank = 50,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x34,
		.edid_std_id = 0xA945,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 1200,
		.refresh_rate_hz = 65.0,
		.pixel_clock_hz = 175500000,
		.horiz_blank = 560,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 192,
		.horiz_border = 0,
		.vert_blank = 50,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x35,
		.edid_std_id = 0xA94A,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 1200,
		.refresh_rate_hz = 70.0,
		.pixel_clock_hz = 189000000,
		.horiz_blank = 560,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 192,
		.horiz_border = 0,
		.vert_blank = 50,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x36,
		.edid_std_id = 0xA94F,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 1200,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 202500000,
		.horiz_blank = 560,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 192,
		.horiz_border = 0,
		.vert_blank = 50,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x37,
		.edid_std_id = 0xA959,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 1200,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 229500000,
		.horiz_blank = 560,
		.horiz_front_porch = 64,
		.horiz_sync_pulse = 192,
		.horiz_border = 0,
		.vert_blank = 50,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x38,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1600,
		.vert_video = 1200,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 268250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 71,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x39,
		.edid_std_id = 0,
		.cvt_id = 0x0C2821,
		.horiz_video = 1680,
		.vert_video = 1050,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 119000000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 30,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x3A,
		.edid_std_id = 0xB300,
		.cvt_id = 0x0C2828,
		.horiz_video = 1680,
		.vert_video = 1050,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 146250000,
		.horiz_blank = 560,
		.horiz_front_porch = 104,
		.horiz_sync_pulse = 176,
		.horiz_border = 0,
		.vert_blank = 39,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x3B,
		.edid_std_id = 0xB30F,
		.cvt_id = 0x0C2844,
		.horiz_video = 1680,
		.vert_video = 1050,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 187000000,
		.horiz_blank = 592,
		.horiz_front_porch = 120,
		.horiz_sync_pulse = 176,
		.horiz_border = 0,
		.vert_blank = 49,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x3C,
		.edid_std_id = 0xB319,
		.cvt_id = 0x0C2868,
		.horiz_video = 1680,
		.vert_video = 1050,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 214750000,
		.horiz_blank = 608,
		.horiz_front_porch = 128,
		.horiz_sync_pulse = 176,
		.horiz_border = 0,
		.vert_blank = 55,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x3D,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1680,
		.vert_video = 1050,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 245500000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 62,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x3E,
		.edid_std_id = 0xC140,
		.cvt_id = 0,
		.horiz_video = 1792,
		.vert_video = 1344,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 204750000,
		.horiz_blank = 656,
		.horiz_front_porch = 128,
		.horiz_sync_pulse = 200,
		.horiz_border = 0,
		.vert_blank = 50,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x3F,
		.edid_std_id = 0xC14F,
		.cvt_id = 0,
		.horiz_video = 1792,
		.vert_video = 1344,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 261000000,
		.horiz_blank = 664,
		.horiz_front_porch = 96,
		.horiz_sync_pulse = 216,
		.horiz_border = 0,
		.vert_blank = 73,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x40,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1792,
		.vert_video = 1344,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 333250000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 79,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x41,
		.edid_std_id = 0xC940,
		.cvt_id = 0,
		.horiz_video = 1856,
		.vert_video = 1392,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 218250000,
		.horiz_blank = 672,
		.horiz_front_porch = 96,
		.horiz_sync_pulse = 224,
		.horiz_border = 0,
		.vert_blank = 47,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x42,
		.edid_std_id = 0xC94F,
		.cvt_id = 0,
		.horiz_video = 1856,
		.vert_video = 1392,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 288000000,
		.horiz_blank = 704,
		.horiz_front_porch = 128,
		.horiz_sync_pulse = 224,
		.horiz_border = 0,
		.vert_blank = 108,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x43,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1856,
		.vert_video = 1392,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 356500000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 82,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x52,
		.edid_std_id = 0xD1C0,
		.cvt_id = 0,
		.horiz_video = 1920,
		.vert_video = 1080,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 148500000,
		.horiz_blank = 280,
		.horiz_front_porch = 88,
		.horiz_sync_pulse = 44,
		.horiz_border = 0,
		.vert_blank = 45,
		.vert_front_porch = 4,
		.vert_sync_pulse = 5,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x44,
		.edid_std_id = 0,
		.cvt_id = 0x572821,
		.horiz_video = 1920,
		.vert_video = 1200,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 154000000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 35,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x45,
		.edid_std_id = 0xD100,
		.cvt_id = 0x572828,
		.horiz_video = 1920,
		.vert_video = 1200,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 193250000,
		.horiz_blank = 672,
		.horiz_front_porch = 136,
		.horiz_sync_pulse = 200,
		.horiz_border = 0,
		.vert_blank = 45,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x46,
		.edid_std_id = 0xD10F,
		.cvt_id = 0x572844,
		.horiz_video = 1920,
		.vert_video = 1200,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 245250000,
		.horiz_blank = 688,
		.horiz_front_porch = 136,
		.horiz_sync_pulse = 208,
		.horiz_border = 0,
		.vert_blank = 55,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x47,
		.edid_std_id = 0xD119,
		.cvt_id = 0x572862,
		.horiz_video = 1920,
		.vert_video = 1200,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 281250000,
		.horiz_blank = 704,
		.horiz_front_porch = 144,
		.horiz_sync_pulse = 208,
		.horiz_border = 0,
		.vert_blank = 62,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x48,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1920,
		.vert_video = 1200,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 317000000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 71,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x49,
		.edid_std_id = 0xD140,
		.cvt_id = 0,
		.horiz_video = 1920,
		.vert_video = 1440,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 234000000,
		.horiz_blank = 680,
		.horiz_front_porch = 128,
		.horiz_sync_pulse = 208,
		.horiz_border = 0,
		.vert_blank = 60,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x4A,
		.edid_std_id = 0xD14F,
		.cvt_id = 0,
		.horiz_video = 1920,
		.vert_video = 1440,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 297000000,
		.horiz_blank = 720,
		.horiz_front_porch = 144,
		.horiz_sync_pulse = 224,
		.horiz_border = 0,
		.vert_blank = 60,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x4B,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 1920,
		.vert_video = 1440,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 380500000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 85,
		.vert_front_porch = 3,
		.vert_sync_pulse = 4,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x54,
		.edid_std_id = 0xE1C0,
		.cvt_id = 0,
		.horiz_video = 2048,
		.vert_video = 1152,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 162000000,
		.horiz_blank = 202,
		.horiz_front_porch = 26,
		.horiz_sync_pulse = 80,
		.horiz_border = 0,
		.vert_blank = 48,
		.vert_front_porch = 1,
		.vert_sync_pulse = 3,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x4C,
		.edid_std_id = 0,
		.cvt_id = 0x1F3821,
		.horiz_video = 2560,
		.vert_video = 1600,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 268500000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 46,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
	{
		.dmt_id = 0x4D,
		.edid_std_id = 0,
		.cvt_id = 0x1F3828,
		.horiz_video = 2560,
		.vert_video = 1600,
		.refresh_rate_hz = 60.0,
		.pixel_clock_hz = 348500000,
		.horiz_blank = 944,
		.horiz_front_porch = 192,
		.horiz_sync_pulse = 280,
		.horiz_border = 0,
		.vert_blank = 58,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x4E,
		.edid_std_id = 0,
		.cvt_id = 0x1F3844,
		.horiz_video = 2560,
		.vert_video = 1600,
		.refresh_rate_hz = 75.0,
		.pixel_clock_hz = 443250000,
		.horiz_blank = 976,
		.horiz_front_porch = 208,
		.horiz_sync_pulse = 280,
		.horiz_border = 0,
		.vert_blank = 72,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x4F,
		.edid_std_id = 0,
		.cvt_id = 0x1F3862,
		.horiz_video = 2560,
		.vert_video = 1600,
		.refresh_rate_hz = 85.0,
		.pixel_clock_hz = 505250000,
		.horiz_blank = 976,
		.horiz_front_porch = 208,
		.horiz_sync_pulse = 280,
		.horiz_border = 0,
		.vert_blank = 82,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = false,
	},
	{
		.dmt_id = 0x50,
		.edid_std_id = 0,
		.cvt_id = 0,
		.horiz_video = 2560,
		.vert_video = 1600,
		.refresh_rate_hz = 120.0,
		.pixel_clock_hz = 552750000,
		.horiz_blank = 160,
		.horiz_front_porch = 48,
		.horiz_sync_pulse = 32,
		.horiz_border = 0,
		.vert_blank = 94,
		.vert_front_porch = 3,
		.vert_sync_pulse = 6,
		.vert_border = 0,
		.reduced_blanking = true,
	},
};

const size_t _di_dmt_timings_len = 86;
